schema

Function schema 

pub fn schema() -> Value
Editor schema generated from the same Rust types used by every map command. Source existence, links, freshness and semantic meaning are outside JSON Schema.