pub struct LogicalPlan {
pub id: String,
pub boolop: PlanSpan,
pub operand: usize,
pub decision: Option<String>,
pub previous_leaves: Option<Vec<usize>>,
pub operand_leaves: Option<Vec<usize>>,
pub short_circuit: String,
pub evaluated: String,
}Fields
id: Stringboolop: PlanSpanoperand: usizeIndex of the right operand this branch describes (1-based within the BoolOp’s operand list).
decision: Option<String>When the BoolOp is part of a decision’s and/or tree, the runtime derives this branch from the decision vector using these leaf index groups: leaves of the previous operand and leaves of this operand.
previous_leaves: Option<Vec<usize>>operand_leaves: Option<Vec<usize>>short_circuit: Stringevaluated: StringTrait Implementations
Sourceimpl Clone for LogicalPlan
impl Clone for LogicalPlan
Sourcefn clone(&self) -> LogicalPlan
fn clone(&self) -> LogicalPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogicalPlan
impl Debug for LogicalPlan
Sourceimpl<'de> Deserialize<'de> for LogicalPlan
impl<'de> Deserialize<'de> for LogicalPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LogicalPlan
Sourceimpl PartialEq for LogicalPlan
impl PartialEq for LogicalPlan
Sourceimpl Serialize for LogicalPlan
impl Serialize for LogicalPlan
impl StructuralPartialEq for LogicalPlan