code

Function code 

pub fn code(path: &str, source: &str) -> Option<Code>
The parser’s view of a file, or None when Supercov has no parser for it or the file does not parse. A file without a view is compared by its bytes.