Language-neutral run integrity fingerprints.
A frontend contributes only its transformation/runtime shim identity. The Rust engine owns source, test, dependency, configuration and execution fingerprints for every language.
Structs
Enums
Constants
Functions
- create_
explicit_ run_ integrity - Language-neutral integrity construction for frontends whose discovery does
not use the JavaScript
CoverageProjectcompatibility structure. - create_
run_ integrity - globally_
tracked - tracked_
manifest - A dependency manifest or lockfile, for any language Supercov supports.