python_integrity_inputs

Function python_integrity_inputs 

pub fn python_integrity_inputs(
    files: &PythonFiles,
    command: &[String],
) -> ExplicitIntegrityInputs
Integrity inputs: sources and tests are hashed separately, dependency and configuration files identify the environment, and the command plus the supervisor environment identify execution.