pub fn python_integrity_inputs(
files: &PythonFiles,
command: &[String],
) -> ExplicitIntegrityInputsExpand description
Integrity inputs: sources and tests are hashed separately, dependency and configuration files identify the environment, and the command plus the supervisor environment identify execution.